@@ -1,12 +1,34 @@
+/*
+
+Copyright (C) 1996, 1997, 1999, 2002, 2003, 2007 John W. Eaton
+
+This file is part of Octave.
+
+Octave is free software; you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by the
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
+
+Octave is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
+
+*/
+
 // hello.cc -- example of a dynamically linked function for Octave.
 
 // To use this file, your version of Octave must support dynamic
 // linking.  To find out if it does, type the command
 //
-//   x = octave_config_info; x.DEFS
+//   octave_config_info ("ENABLE_DYNAMIC_LINKING")
 //
 // at the Octave prompt.  Support for dynamic linking is included if
-// the output contains the string -DWITH_DYNAMIC_LINKING=1.
+// this expression returns the string "true".
 //
 // To compile this file, type the command
 //
@@ -48,7 +70,7 @@
 
 #include <octave/config.h>
 
-#include <iostream.h>
+#include <iostream>
 
 #include <octave/defun-dld.h>
 #include <octave/error.h>
