@@ -401,21 +401,7 @@ Array<T>::reshape (const dim_vector& new_dims) const
   return retval;
 }
 
-struct
-permute_vector
-{
-  octave_idx_type pidx;
-  octave_idx_type iidx;
-};
 
-static int
-permute_vector_compare (const void *a, const void *b)
-{
-  const permute_vector *pva = static_cast<const permute_vector *> (a);
-  const permute_vector *pvb = static_cast<const permute_vector *> (b);
-
-  return pva->pidx > pvb->pidx;
-}
 
 template <class T>
 Array<T>
@@ -2260,7 +2246,7 @@ Array<T>::indexN (idx_vector& ra_idx, int resize_ok, const T& rfv) const
 	{
 	  dim_vector result_dims;
 
-	  if (vec_equiv)
+	  if (vec_equiv && ! orig_len == 1)
 	    {
 	      result_dims = dv;
 
@@ -2315,7 +2301,13 @@ Array<T>::index (idx_vector& idx_i, idx_vector& idx_j, int resize_ok,
 {
   Array<T> retval;
 
-  assert (ndims () == 2);
+  if (ndims () != 2)
+    {
+      Array<idx_vector> ra_idx (2);
+      ra_idx(0) = idx_i;
+      ra_idx(1) = idx_j;
+      return index (ra_idx, resize_ok, rfv);
+    }
 
   octave_idx_type nr = dim1 ();
   octave_idx_type nc = dim2 ();
