@@ -1,13 +1,14 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1998, 2002, 2003, 2004, 2005, 2006, 2007
+              John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +16,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -160,6 +160,9 @@ erfc (double x)
 double
 xgamma (double x)
 {
+#if defined (HAVE_TGAMMA)
+  return tgamma (x);
+#else
   double result;
 
   if (xisnan (x))
@@ -168,23 +171,29 @@ xgamma (double x)
     result = octave_Inf;
   else
     F77_XFCN (xdgamma, XDGAMMA, (x, result));
+
   return result;
+#endif
 }
 
 double
 xlgamma (double x)
 {
+#if defined (HAVE_LGAMMA)
+  return lgamma (x);
+#else
   double result;
   double sgngam;
 
   if (xisnan (x))
     result = x;
-  else if (x <= 0 || xisinf (x))
+  else if (xisinf (x))
     result = octave_Inf;
   else
     F77_XFCN (dlgams, DLGAMS, (x, result, sgngam));
 
   return result;
+#endif
 }
 
 static inline Complex
@@ -402,9 +411,8 @@ zbesi (const Complex& z, double alpha, int kode, octave_idx_type& ierr)
 
       if (ierr == 0 || ierr == 3)
 	{
-	  if (! is_integer_value (alpha - 0.5))
-	    tmp += (2.0 / M_PI) * sin (M_PI * alpha)
-	      * zbesk (z, alpha, kode, ierr);
+	  tmp += (2.0 / M_PI) * sin (M_PI * alpha)
+	    * zbesk (z, alpha, kode, ierr);
 
 	  retval = bessel_return_value (tmp, ierr);
 	}
