@@ -1,21 +1,20 @@
-## Copyright (C) 1996, 1998 Kai P. Mueller
+## Copyright (C) 1996, 1998, 2000, 2004, 2005, 2007 Kai P. Mueller
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
-## under the terms of the GNU General Public License as published by the
-## Free Software Foundation; either version 2, or (at your option) any
-## later version.
+## under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but WITHOUT
-## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-## for more details.
+## Octave is distributed in the hope that it will be useful, but
+## WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301 USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} hinfdemo ()
@@ -63,7 +62,7 @@
 ## @end example
 ## @end ifinfo
 ##
-## @example
+## @smallexample
 ## @group
 ##
 ##                               +----+
@@ -79,7 +78,7 @@
 ##          -----| K |<-------
 ##               +---+
 ## @end group
-## @end example
+## @end smallexample
 ## 
 ## @iftex
 ## @tex
@@ -108,7 +107,7 @@
 ## @end ifinfo
 ## norm of the
 ## augmented plant @var{P} (mixed-sensitivity problem):
-## @example
+## @smallexample
 ## @group
 ##      w
 ##       1 -----------+
@@ -125,7 +124,7 @@
 ##             u                       y (to K)
 ##          (from controller K)
 ## @end group
-## @end example
+## @end smallexample
 ##
 ## @iftex
 ## @tex
@@ -138,7 +137,7 @@
 ## @end tex
 ## @end iftex
 ## @ifinfo
-## @example
+## @smallexample
 ## @group
 ##                   +    +           +    +
 ##                   | z  |           | w  |
@@ -148,7 +147,7 @@
 ##                   | y  |           | u  |
 ##                   +    +           +    +
 ## @end group
-## @end example
+## @end smallexample
 ## @end ifinfo
 ##
 ## @item Discrete system:
@@ -193,7 +192,7 @@
 ## @end example
 ## @end ifinfo
 ##
-## @example
+## @smallexample
 ## @group
 ##
 ##                               +----+
@@ -209,7 +208,7 @@
 ##          -----| K |<-------
 ##               +---+
 ## @end group
-## @end example
+## @end smallexample
 ## @iftex
 ## @tex
 ## $$ { \rm min } \Vert T_{vz} \Vert _\infty $$
