@@ -64,7 +64,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
       fputs (plot_stream, "set size noratio;\n");
     endif
 
-    fputs (plot_stream, "set pm3d;\n");
+    fputs (plot_stream, "set pm3d explicit;\n");
     fputs (plot_stream, "unset label;\n");
 
     if (! isempty (axis_obj.title))
@@ -185,6 +185,9 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
     else
       xaxisloc = "x";
       xaxisloc_using = "x1";
+      if (strcmpi (axis_obj.xaxislocation, "zero"))
+	fputs (plot_stream, "set xzeroaxis;\n");
+      endif
     endif
     if (strcmpi (axis_obj.yaxislocation, "right"))
       yaxisloc = "y2";
@@ -192,6 +195,9 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
     else
       yaxisloc = "y";
       yaxisloc_using = "y1";
+      if (strcmpi (axis_obj.yaxislocation, "zero"))
+	fputs (plot_stream, "set yzeroaxis;\n");
+      endif
     endif
 
     have_grid = false;
@@ -241,9 +247,13 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
       fputs (plot_stream, "set grid nomztics;\n");
     endif
 
-    ## Unless we force the grid to the front, tics may appear below
-    ## plotted objects.
-    fputs (plot_stream, "set grid front;\n");
+    ## The grid front/back/layerdefault option also controls the
+    ## appearance of tics, so it is used even if the grid is absent.
+    if (strcmpi (axis_obj.layer, "top"))
+      fputs (plot_stream, "set grid front;\n");
+    else
+      fputs (plot_stream, "set grid layerdefault;\n");
+    endif
     if (! have_grid)
       fputs (plot_stream, "unset grid;\n");
     endif
@@ -278,7 +288,15 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 
     kids = axis_obj.children;
 
-    nd = 0;
+    nd = __calc_dimensions__ (axis_obj);
+
+    if (nd == 3)
+      fputs (plot_stream, "set parametric;\n");
+      fputs (plot_stream, "set style data lines;\n");
+      fputs (plot_stream, "set surface;\n");
+      fputs (plot_stream, "unset contour;\n");
+    endif
+
     data_idx = 0;
     data = cell ();
     is_image_data = [];
@@ -307,14 +325,6 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 
       switch (obj.type)
 	case "image"
-	  ## FIXME - Is there a better way to determine if the plot
-	  ## command should be "plot" or "splot"?????  Could have images
-	  ## projected into 3D so there is really no reason to limit
-	  ## this.
-	  if (nd == 0)
-	    nd = 2;
-	  endif
-
 	  img_data = obj.cdata;
 	  img_xdata = obj.xdata;
 	  img_ydata = obj.ydata;
@@ -387,20 +397,18 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 	    withclause{data_idx} = sprintf ("with %s linetype %d",
 					    style, typ);
 	  endif
-	  if (! isempty (obj.zdata))
-	    nd = 3;
+	  if (nd == 3)
 	    xdat = obj.xdata(:);
 	    ydat = obj.ydata(:);
-	    zdat = obj.zdata(:);
-
+	    if (! isempty (obj.zdata))
+	      zdat = obj.zdata(:);
+	    else
+	      zdat = zeros (size (xdat));
+	    endif
 	    data{data_idx} = [xdat, ydat, zdat]';
 	    usingclause{data_idx} = "using ($1):($2):($3)";
-	    fputs (plot_stream, "set parametric;\n");
-	    fputs (plot_stream, "set style data lines;\n");
-	    fputs (plot_stream, "set surface;\n");
-	    fputs (plot_stream, "unset contour;\n");
+	    ## fputs (plot_stream, "set parametric;\n");
 	  else
-	    nd = 2;
 	    xdat = obj.xdata(:);
 	    ydat = obj.ydata(:);
 	    ldat = obj.ldata;
@@ -494,24 +502,24 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 	 for i = 1:nc
 	   xcol = obj.xdata(:,i);
 	   ycol = obj.ydata(:,i);
-	   if (! isempty (obj.zdata))
-	     zcol = obj.zdata(:,i);
-	   else
-	     zcol = [];
+	   if (nd == 3)
+	     if (! isempty (obj.zdata))
+	       zcol = obj.zdata(:,i);
+	     else
+	       zcol = zeros (size (xcol));
+	     endif
 	   endif
 
 	   if (! isnan (xcol) && ! isnan (ycol))
 	     ## Is the patch closed or not
 	     if (strncmp (obj.facecolor, "none", 4)) 
-	       if (isnan (hidden_removal))
-		 hidden_removal = false;
-	       endif
+	       hidden_removal = false;
 	     else
-	       hidden_removal = true;
-	       if (! isempty (zcol))
+	       if (isnan (hidden_removal))
+		 hidden_removal = true;
+	       endif
+	       if (nd == 3)
 		 error ("gnuplot (as of v4.2) only supports 2D filled patches");
-	       else
-		 nd = 2;
 	       endif
 
 	       data_idx++;
@@ -606,11 +614,6 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 
            ## patch outline
 	   if (! strncmp (obj.edgecolor, "none", 4))
-	     if (! isempty (zcol))
-	       nd = 3;
-	     else
-	       nd = 2;
-	     endif
 
 	     data_idx++;
              is_image_data(data_idx) = false;
@@ -669,13 +672,13 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 	     if (isfield (obj, "linestyle"))
 	       switch (obj.linestyle)
 		 case "-"
-		   lt = "1";
+		   lt = "lt 1";
 		 case "--"
-		   lt = "2";
+		   lt = "lt 2";
 		 case ":"
-		   lt = "3";
+		   lt = "lt 3";
 		 case "-."
-		   lt = "6";
+		   lt = "lt 6";
 		 case "none"
 		   lt = "";
 		 otherwise
@@ -759,8 +762,8 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 		 colorspec = sprintf ("lc rgb \"#%02x%02x%02x\"",
 				      round (255*color));
 	       endif
-	       withclause{data_idx} = sprintf ("with %s %s %s %s",
-					       style, pt, ps, colorspec);
+	       withclause{data_idx} = sprintf ("with %s %s %s %s %s",
+					       style, pt, lt, ps, colorspec);
 	     else
 	       if (isequal (color, [0,0,0]))
 		 typ = -1;
@@ -785,7 +788,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 					       style, pt, ps, typ);
 	     endif
 
-	     if (! isempty (zcol))
+	     if (nd == 3)
 	       if (! isnan (xcol) && ! isnan (ycol) && ! isnan (zcol))
 		 data{data_idx} = [[xcol; xcol(1)], [ycol; ycol(1)], ...
 				   [zcol; zcol(1)]]';
@@ -805,7 +808,6 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 	 endfor
 
 	case "surface"
-	  nd = 3;
 	  view_map = true;
           if (! (strncmp (obj.edgecolor, "none", 4)
 		 && strncmp (obj.facecolor, "none", 4)))
@@ -823,11 +825,11 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 	    endif
 	    usingclause{data_idx} = "";
 	    if (have_newer_gnuplot || isnan (typ))
-	      withclause{data_idx} = sprintf ("with %s linestyle %d",
-		           		      style, data_idx);
+	      withclause{data_idx} = sprintf ("with pm3d linestyle %d",
+		           		      data_idx);
 	    else
-	      withclause{data_idx} = sprintf ("with %s linetype %d %s",
-		 			      style, typ, with);
+	      withclause{data_idx} = sprintf ("with pm3d linetype %d %s",
+		 			      typ, with);
 	    endif
 
 	    xdat = obj.xdata;
@@ -873,11 +875,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 	      data{data_idx} = zz.';
 	    endif
 	    usingclause{data_idx} = "using ($1):($2):($3):($4)";
-
-	    fputs (plot_stream, "unset parametric;\n");
-	    fputs (plot_stream, "set style data lines;\n");
-	    fputs (plot_stream, "set surface;\n");
-	    fputs (plot_stream, "unset contour;\n");
+	    ## fputs (plot_stream, "unset parametric;\n");
 
 	    ## Interpolation does not work for flat surfaces (e.g. pcolor)
             ## and color mapping --> currently set empty.
@@ -891,15 +889,14 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 				       || (isnumeric (obj.facecolor)
 					   && all (obj.facecolor == 1)));
 	    if (strncmp (obj.facecolor, "none", 4))
-	      if (isnan (hidden_removal))
-		hidden_removal = false;
-	      endif
+	      hidden_removal = false;
 	    else
-	      hidden_removal = true;
+	      if (isnan (hidden_removal))
+		hidden_removal = true;
+	      endif
 	    endif
-
-            if (flat_interp_face
-		|| (flat_interp_edge && facecolor_none_or_white))
+	    
+            if (flat_interp_edge && facecolor_none_or_white)
 	      withclause{data_idx} = "with line palette";
             endif
 
@@ -909,22 +906,19 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 	      dord = "";
 	    endif
 
-	    if (facecolor_none_or_white)
-	      ## Ensure faces aren't drawn
-	      fprintf (plot_stream, "unset pm3d;\n");
-            elseif (flat_interp_face && strncmp (obj.edgecolor, "flat", 4))
-              fprintf (plot_stream, "set pm3d at s %s %s corners2color c3;\n", 
+	    if (flat_interp_face && strncmp (obj.edgecolor, "flat", 4))
+              fprintf (plot_stream, "set pm3d explicit at s %s %s corners2color c3;\n", 
 		       interp_str, dord);
-            else
+            elseif (!facecolor_none_or_white)
               if (strncmp (obj.edgecolor, "none", 4))
-                fprintf (plot_stream, "set pm3d at s %s corners2color c3;\n", 
+                fprintf (plot_stream, "set pm3d explicit at s %s corners2color c3;\n", 
 			 interp_str, dord);
               else
                 edgecol = obj.edgecolor;
                 if (ischar (obj.edgecolor))
                   edgecol = [0,0,0];
                 endif
-                fprintf (plot_stream, "set pm3d at s hidden3d %d %s %s corners2color c3;\n", 
+                fprintf (plot_stream, "set pm3d explicit at s hidden3d %d %s %s corners2color c3;\n", 
 			 data_idx, interp_str, dord);
 
 		if (have_newer_gnuplot)
@@ -1063,8 +1057,25 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
       if (nd == 3)
 	fputs (plot_stream, "set border 895;\n");
       else
-	fputs (plot_stream, "set border 3;\n");
-	fputs (plot_stream, "set xtics nomirror; set ytics nomirror;\n");
+	if (strcmpi (axis_obj.yaxislocation, "right"))
+	  fputs (plot_stream, "unset ytics; set y2tics nomirror\n");
+	  if (strcmpi (axis_obj.xaxislocation, "top"))
+	    fputs (plot_stream, "unset xtics; set x2tics nomirror\n");
+	    fputs (plot_stream, "set border 12;\n");
+	  else
+	    fputs (plot_stream, "unset x2tics; set xtics nomirror\n");
+	    fputs (plot_stream, "set border 9;\n");
+	  endif
+	else
+	  fputs (plot_stream, "unset y2tics; set ytics nomirror\n");
+	  if (strcmpi (axis_obj.xaxislocation, "top"))
+	    fputs (plot_stream, "unset xtics; set x2tics nomirror\n");
+	    fputs (plot_stream, "set border 6;\n");
+	  else
+	    fputs (plot_stream, "unset x2tics; set xtics nomirror\n");
+	    fputs (plot_stream, "set border 3;\n");
+	  endif
+	endif
       endif
     endif
 
@@ -1389,6 +1400,24 @@ function [style, typ, with] = do_linestyle_command (obj, idx, mono, plot_stream)
 
 endfunction
 
+function nd = __calc_dimensions__ (obj)
+  kids = obj.children;
+  nd = 2;
+  for i = 1:length (kids)
+    obj = get (kids(i));
+    switch (obj.type)
+      case {"image", "text"}
+	## ignore as they 
+      case {"line", "patch"}
+	if (! isempty (obj.zdata))
+	  nd = 3;
+	endif
+      case "surface"
+	nd = 3;
+    endswitch
+  endfor
+endfunction
+
 function __gnuplot_write_data__ (plot_stream, data, nd, parametric, cdata)
   
   ## DATA is already transposed.
@@ -1447,32 +1476,42 @@ endfunction
 function do_tics (obj, plot_stream, ymirror, mono)
   if (strcmpi (obj.xaxislocation, "top"))
     do_tics_1 (obj.xtickmode, obj.xtick, obj.xticklabelmode, obj.xticklabel,
-	       obj.xcolor, "x2", plot_stream, true, mono);
+	       obj.xcolor, "x2", plot_stream, true, mono, "border");
     do_tics_1 ("manual", [], obj.xticklabelmode, obj.xticklabel,
-	       obj.xcolor, "x", plot_stream, true, mono);
+	       obj.xcolor, "x", plot_stream, true, mono, "border");
+  elseif (strcmpi (obj.xaxislocation, "zero"))
+    do_tics_1 (obj.xtickmode, obj.xtick, obj.xticklabelmode, obj.xticklabel,
+	       obj.xcolor, "x", plot_stream, true, mono, "axis");
+    do_tics_1 ("manual", [], obj.xticklabelmode, obj.xticklabel,
+	       obj.xcolor, "x2", plot_stream, true, mono, "axis");
   else
     do_tics_1 (obj.xtickmode, obj.xtick, obj.xticklabelmode, obj.xticklabel,
-	       obj.xcolor, "x", plot_stream, true, mono);
+	       obj.xcolor, "x", plot_stream, true, mono, "border");
     do_tics_1 ("manual", [], obj.xticklabelmode, obj.xticklabel,
-	       obj.xcolor, "x2", plot_stream, true, mono);
+	       obj.xcolor, "x2", plot_stream, true, mono, "border");
   endif
   if (strcmpi (obj.yaxislocation, "right"))
     do_tics_1 (obj.ytickmode, obj.ytick, obj.yticklabelmode, obj.yticklabel,
-	       obj.ycolor, "y2", plot_stream, ymirror, mono);
+	       obj.ycolor, "y2", plot_stream, ymirror, mono, "border");
     do_tics_1 ("manual", [], obj.yticklabelmode, obj.yticklabel,
-	       obj.ycolor, "y", plot_stream, ymirror, mono);
+	       obj.ycolor, "y", plot_stream, ymirror, mono, "border");
+  elseif (strcmpi (obj.xaxislocation, "zero"))
+    do_tics_1 (obj.ytickmode, obj.ytick, obj.yticklabelmode, obj.yticklabel,
+	       obj.ycolor, "y", plot_stream, ymirror, mono, "axis");
+    do_tics_1 ("manual", [], obj.yticklabelmode, obj.yticklabel,
+	       obj.ycolor, "y2", plot_stream, ymirror, mono, "axis");
   else
     do_tics_1 (obj.ytickmode, obj.ytick, obj.yticklabelmode, obj.yticklabel,
-	       obj.ycolor, "y", plot_stream, ymirror, mono);
+	       obj.ycolor, "y", plot_stream, ymirror, mono, "border");
     do_tics_1 ("manual", [], obj.yticklabelmode, obj.yticklabel,
-	       obj.ycolor, "y2", plot_stream, ymirror, mono);
+	       obj.ycolor, "y2", plot_stream, ymirror, mono, "border");
   endif
   do_tics_1 (obj.ztickmode, obj.ztick, obj.zticklabelmode, obj.zticklabel,
-	     obj.zcolor, "z", plot_stream, true, mono);
+	     obj.zcolor, "z", plot_stream, true, mono, "border");
 endfunction
 
 function do_tics_1 (ticmode, tics, labelmode, labels, color, ax,
-		    plot_stream, mirror, mono)
+		    plot_stream, mirror, mono, axispos)
   colorspec = get_text_colorspec (color, mono);
   if (strcmpi (ticmode, "manual"))
     if (isempty (tics))
@@ -1487,9 +1526,9 @@ function do_tics_1 (ticmode, tics, labelmode, labels, color, ax,
 	nlabels = numel (labels);
 	fprintf (plot_stream, "set format %s \"%%s\";\n", ax);
 	if (mirror)
-	  fprintf (plot_stream, "set %stics (", ax);
+	  fprintf (plot_stream, "set %stics %s (", ax, axispos);
 	else
-	  fprintf (plot_stream, "set %stics nomirror (", ax);
+	  fprintf (plot_stream, "set %stics %s nomirror (", ax, axispos);
 	endif
 	labels = regexprep(labels, "%", "%%");
 	for i = 1:ntics
@@ -1508,9 +1547,9 @@ function do_tics_1 (ticmode, tics, labelmode, labels, color, ax,
     else
       fprintf (plot_stream, "set format %s \"%%g\";\n", ax);
       if (mirror)
-	fprintf (plot_stream, "set %stics (", ax);
+	fprintf (plot_stream, "set %stics %s (", ax, axispos );
       else
-	fprintf (plot_stream, "set %stics nomirror (", ax);
+	fprintf (plot_stream, "set %stics %s nomirror (", ax, axispos);
       endif
       fprintf (plot_stream, " %g,", tics(1:end-1));
       fprintf (plot_stream, " %g);\n", tics(end));
@@ -1518,9 +1557,10 @@ function do_tics_1 (ticmode, tics, labelmode, labels, color, ax,
   else
     fprintf (plot_stream, "set format %s \"%%g\";\n", ax);
     if (mirror)
-      fprintf (plot_stream, "set %stics %s;\n", ax, colorspec);
+      fprintf (plot_stream, "set %stics %s %s;\n", ax, axispos, colorspec);
     else
-      fprintf (plot_stream, "set %stics nomirror %s;\n", ax, colorspec);
+      fprintf (plot_stream, "set %stics %s nomirror %s;\n", ax, 
+	       axispos, colorspec);
     endif
   endif
 endfunction
