@@ -72,7 +72,10 @@
 ##   @item emf
 ##     Microsoft Enhanced Metafile
 ##   @item fig
-##     XFig
+##     XFig.  If this format is selected the additional options
+##     @code{-textspecial} or @code{-textnormal} can be used to control
+##     whether the special flag should be set for the text in the figure
+##     (default is @code{-textnormal}). 
 ##   @item hpgl
 ##     HP plotter language
 ##   @item mf
@@ -127,6 +130,11 @@ function print (varargin)
   printer = "";
   debug = false;
   debug_file = "octave-print-commands.log";
+  special_flag = "textnormal";
+
+  ## Ensure the last figure is on the screen for single line commands like
+  ##   plot(...); print(...);
+  drawnow ();
 
   for i = 1:nargin
     arg = varargin{i};
@@ -143,6 +151,8 @@ function print (varargin)
 	orientation = "portrait";
       elseif (strcmp (arg, "-landscape"))
 	orientation = "landscape";
+      elseif (strcmp (arg, "-textspecial"))
+	special_flag = "textspecial";
       elseif (strncmp (arg, "-debug", 6))
 	debug = true;
 	if (length (arg) > 7)
@@ -247,7 +257,6 @@ function print (varargin)
       else
 	options = strcat (orientation, " ");
       endif
-      options = strcat (options, "enhanced ");
       termn = "postscript";
     endif
     
@@ -298,12 +307,14 @@ function print (varargin)
     else
       options = " mono";
     endif
+    options = strcat (options, " ", special_flag);
     if (! isempty (fontsize))
       options = strcat (options, " fontsize ", fontsize);
     endif
 
     new_terminal = strcat ("fig ", options);
 
+
   elseif (strcmp (dev, "emf"))
     ## Enhanced Metafile format
     options = " ";
@@ -361,10 +372,12 @@ function print (varargin)
 
   endif
 
+  mono = use_color < 0;
+
   if (debug)
-    drawnow (new_terminal, name, debug_file);
+    drawnow (new_terminal, name, mono, debug_file);
   else
-    drawnow (new_terminal, name);
+    drawnow (new_terminal, name, mono);
   endif
 
   if (! isempty (convertname))
