@@ -1,12 +1,14 @@
 /*
 
-Copyright (C) 2005 David Bateman
-Copyright (C) 1998-2005 Andy Adler
+Copyright (C) 2005, 2006, 2007 David Bateman
+Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 Andy Adler
+
+This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -14,9 +16,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; see the file COPYING.  If not, write to the
-Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-Boston, MA 02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -147,13 +148,13 @@ as\n\
 The deactivated tests below can't be tested till rectangular back-subs is
 implemented for sparse matrices.
 
-%!test
+%!testif HAVE_CXSPARSE
 %! n = 20; d= 0.2;
 %! a = sprandn(n,n,d)+speye(n,n);
 %! r = spqr(a);
 %! assert(r'*r,a'*a,1e-10)
 
-%!test
+%!testif HAVE_CXSPARSE
 %! n = 20; d= 0.2;
 %! a = sprandn(n,n,d)+speye(n,n);
 %! q = symamd(a);
@@ -161,13 +162,13 @@ implemented for sparse matrices.
 %! r = spqr(a);
 %! assert(r'*r,a'*a,1e-10)
 
-%!test
+%!testif HAVE_CXSPARSE
 %! n = 20; d= 0.2;
 %! a = sprandn(n,n,d)+speye(n,n);
 %! [c,r] = spqr(a,ones(n,1));
 %! assert (r\c,full(a)\ones(n,1),10e-10)
 
-%!test
+%!testif HAVE_CXSPARSE
 %! n = 20; d= 0.2;
 %! a = sprandn(n,n,d)+speye(n,n);
 %! b = randn(n,2);
@@ -175,20 +176,20 @@ implemented for sparse matrices.
 %! assert (r\c,full(a)\b,10e-10)
 
 %% Test under-determined systems!!
-%!#test
+%!#testif HAVE_CXSPARSE
 %! n = 20; d= 0.2;
 %! a = sprandn(n,n+1,d)+speye(n,n+1);
 %! b = randn(n,2);
 %! [c,r] = spqr(a,b);
 %! assert (r\c,full(a)\b,10e-10)
 
-%!test
+%!testif HAVE_CXSPARSE
 %! n = 20; d= 0.2;
 %! a = 1i*sprandn(n,n,d)+speye(n,n);
 %! r = spqr(a);
 %! assert(r'*r,a'*a,1e-10)
 
-%!test
+%!testif HAVE_CXSPARSE
 %! n = 20; d= 0.2;
 %! a = 1i*sprandn(n,n,d)+speye(n,n);
 %! q = symamd(a);
@@ -196,13 +197,13 @@ implemented for sparse matrices.
 %! r = spqr(a);
 %! assert(r'*r,a'*a,1e-10)
 
-%!test
+%!testif HAVE_CXSPARSE
 %! n = 20; d= 0.2;
 %! a = 1i*sprandn(n,n,d)+speye(n,n);
 %! [c,r] = spqr(a,ones(n,1));
 %! assert (r\c,full(a)\ones(n,1),10e-10)
 
-%!test
+%!testif HAVE_CXSPARSE
 %! n = 20; d= 0.2;
 %! a = 1i*sprandn(n,n,d)+speye(n,n);
 %! b = randn(n,2);
@@ -210,7 +211,7 @@ implemented for sparse matrices.
 %! assert (r\c,full(a)\b,10e-10)
 
 %% Test under-determined systems!!
-%!#test
+%!#testif HAVE_CXSPARSE
 %! n = 20; d= 0.2;
 %! a = 1i*sprandn(n,n+1,d)+speye(n,n+1);
 %! b = randn(n,2);
@@ -351,12 +352,12 @@ triangular form of a sparse matrix. ACM Trans. Math. Software,\n\
 
 /* 
 
-%!test
+%!testif HAVE_CXSPARSE
 %! n=20;
 %! a=speye(n,n);a=a(randperm(n),:);
 %! assert(a(dmperm(a),:),speye(n))
 
-%!test
+%!testif HAVE_CXSPARSE
 %! n=20;
 %! d=0.2;
 %! a=tril(sprandn(n,n,d),-1)+speye(n,n);
@@ -401,8 +402,10 @@ rank (@var{s})}.\n\
 /* 
 
 %!error(sprank(1,2));
-%!assert(sprank(speye(20)), 20)
-%!assert(sprank([1,0,2,0;2,0,4,0]),2)
+%!testif HAVE_CXSPARSE
+%! assert(sprank(speye(20)), 20)
+%!testif HAVE_CXSPARSE
+%! assert(sprank([1,0,2,0;2,0,4,0]),2)
 
 */
 /*
