@@ -790,6 +790,13 @@ EOF
 # =======================================================
 # sparse selection tests
 
+gen_scalar_select_tests () {
+    cat >>$TESTS <<EOF
+%!assert (sparse(42)([1,1]),sparse([42,42]))
+%!assert (sparse(42*1i)([1,1]),sparse([42,42].*1i))
+EOF
+}
+
 gen_select_tests() {
     cat >>$TESTS <<EOF
 %!test as=sparse(af);
@@ -811,6 +818,13 @@ gen_select_tests() {
 %!assert(as((size(as,1):-1:1),:),sparse(af((size(af,1):-1:1),:)))
 %!assert(as(:,(size(as,2):-1:1)),sparse(af(:,(size(af,2):-1:1))))
 
+%% Indexing tests
+%!assert(full(as([1,1],:)), af([1,1],:))
+%!assert(full(as(:,[1,1])), af(:,[1,1]))
+%!test
+%! [i,j,v] = find (as);
+%! assert (as(i(1),j(1))([1,1]), sparse([v(1),v(1)]))
+
 %% Assignment test
 %!test
 %! ts=as;ts(:,:)=ts(fliplr(1:size(as,1)),:);
@@ -1219,6 +1233,7 @@ else
 %! cidx = ceil(n*rand(1,ceil(rand*n))
 EOF
 fi
+gen_scalar_select_tests
 gen_select_tests
 echo '%!test af=real(af);' >> $TESTS
 gen_select_tests
