@@ -1,3 +1,21 @@
+## Copyright (C) 2005, 2006, 2007 David Bateman
+##
+## This file is part of Octave.
+##
+## Octave is free software; you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
+##
+## Octave is distributed in the hope that it will be useful, but
+## WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+## General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
+
 clear all;
 
 global files_with_no_tests = {};
@@ -58,11 +76,11 @@ function y = hastests (f)
        || findstr (str, "%!error") || findstr (str, "%!warning"));
 endfunction
 
-function [dp, dn, dxf] = run_test_dir (fid, d);
+function [dp, dn, dxf, dsk] = run_test_dir (fid, d);
   global files_with_tests;
   global files_with_no_tests;
   lst = dir (d);
-  dp = dn = dxf = 0;
+  dp = dn = dxf = dsk = 0;
   for i = 1:length (lst)
     nm = lst(i).name;
     if (length (nm) > 5 && strcmp (nm(1:5), "test_")
@@ -71,7 +89,7 @@ function [dp, dn, dxf] = run_test_dir (fid, d);
       ffnm = fullfile (d, nm);
       if (hastests (ffnm))
 	print_test_file_name (nm);
-	[p, n, xf] = test (nm(1:(end-2)), "quiet", fid);
+	[p, n, xf, sk] = test (nm(1:(end-2)), "quiet", fid);
 	print_pass_fail (n, p);
 	files_with_tests(end+1) = ffnm;
       else
@@ -80,25 +98,27 @@ function [dp, dn, dxf] = run_test_dir (fid, d);
       dp += p;
       dn += n;
       dxf += xf;
+      dsk += sk;
     endif
   endfor
 endfunction
 
-function [dp, dn, dxf] = run_test_script (fid, d);
+function [dp, dn, dxf, dsk] = run_test_script (fid, d);
   global files_with_tests;
   global files_with_no_tests;
   global topsrcdir;
   global topbuilddir;
   lst = dir (d);
-  dp = dn = dxf = 0;
+  dp = dn = dxf = dsk = 0;
   for i = 1:length (lst)
     nm = lst(i).name;
     if (lst(i).isdir && ! strcmp (nm, ".") && ! strcmp (nm, "..")
 	&& ! strcmp (nm, "CVS"))
-      [p, n, xf] = run_test_script (fid, [d, "/", nm]);
+      [p, n, xf, sk] = run_test_script (fid, [d, "/", nm]);
       dp += p;
       dn += n;
       dxf += xf;
+      dsk += sk;
     endif
   endfor
   for i = 1:length (lst)
@@ -112,11 +132,12 @@ function [dp, dn, dxf] = run_test_script (fid, d);
 	tmp = strrep (f, [topsrcdir, "/"], "");
 	tmp = strrep (tmp, [topbuilddir, "/"], "../");
 	print_test_file_name (tmp);
-	[p, n, xf] = test (f, "quiet", fid);
+	[p, n, xf, sk] = test (f, "quiet", fid);
 	print_pass_fail (n, p);
 	dp += p;
 	dn += n;
 	dxf += xf;
+	dsk += sk;
 	files_with_tests(end+1) = f;
       else
 	files_with_no_tests(end+1) = f;
@@ -153,30 +174,46 @@ try
     error ("could not open fntests.log for writing");
   endif
   test ("", "explain", fid);
-  dp = dn = dxf = 0;
+  dp = dn = dxf = dsk = 0;
   printf ("\nIntegrated test scripts:\n\n");
   for i = 1:length (fundirs)
-    [p, n, xf] = run_test_script (fid, fundirs{i});
+    [p, n, xf, sk] = run_test_script (fid, fundirs{i});
     dp += p;
     dn += n;
     dxf += xf;
+    dsk += sk;
   endfor
   printf ("\nFixed test scripts:\n\n");
   for i = 1:length (testdirs)
-    [p, n, xf] = run_test_dir (fid, testdirs{i});
+    [p, n, xf, sk] = run_test_dir (fid, testdirs{i});
     dp += p;
     dn += n;
     dxf += xf;
+    dsk += sk;
   endfor
   printf ("\nSummary:\n\n  PASS %6d\n", dp);
   nfail = dn - dp;
   printf ("  FAIL %6d\n", nfail);
   if (dxf > 0)
-    printf ("\nThere were %d expected failures (see fntests.log for details).\n",
-	    dxf);
+    if (dxf > 1)
+      t1 = "were";
+      t2 = "failures";
+    else
+      t1 = "was";
+      t2 = "failure";
+    endif
+    printf ("\nThere %s %d expected %s (see fntests.log for details).\n",
+	    t1, dxf, t2);
     printf ("\nExpected failures are known bugs. Please help improve\n");
     printf ("Octave by contributing fixes for them.\n");
   endif
+  if (dsk > 0)
+    printf ("\nThere were %d skipped tests (see fntest.log for details).\n", dsk);
+    printf ("Skipped tests are features that are disabled in this version\n");
+    printf ("of Octave as the needed libraries were not present when Octave\n");
+    printf ("was built\n");
+  endif
+
   n_files_with_no_tests = length (files_with_no_tests);
   n_files = n_files_with_no_tests + length (files_with_tests);
   printf ("\n%d (of %d) files have no tests.  Please help improve Octave by\n",
